#!/usr/bin/python
# -*- coding: utf-8 -*-

'''*
	Copyright (C) 2015 DudeHere

	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
*'''

import sys
from dudehere.routines import *
from dudehere.routines import plugin
from dudehere.routines.plugin import ContextMenu, ProgressBar
from resources.lib.constants import *
from resources.lib.i18n_strings import STRINGS as STRINGS_MAP
from dudehere.routines.validators import *


STRINGS = STRINGS_MAP()

plugin.replace_context_menu_by_default = True
plugin.default_context_menu_items = [
	('More Options', {'mode': 'more_options'}, True, True),
	("Add-on Settings", {"mode": "redbeard_settings", "addon_id": ADDON_ID}, True)
]

CONTEXT_MORE_OPTIONS = []
CONTEXT_MORE_OPTIONS_TABLE = {
		"Cloud Manager": "cloud_manager",	
		"Manage Scrapers": "manage_scrapers",
		"Transmogrifier Queue": "manage_transmogrifier",
		"Walter Sobchak": "manage_walter",
}
def more_options_window():
	CONTEXT_MORE_OPTIONS.append("Cloud Manager")
	CONTEXT_MORE_OPTIONS.append("Manage Scrapers")
	if validate_transmogrifier(): CONTEXT_MORE_OPTIONS.append("Transmogrifier Queue")
	if validate_walter(): CONTEXT_MORE_OPTIONS.append("Walter Sobchak")	
	choice = plugin.dialog_select("More Options", CONTEXT_MORE_OPTIONS)
	if choice is not False:
		mode = CONTEXT_MORE_OPTIONS_TABLE[CONTEXT_MORE_OPTIONS[choice]]
		query = {"mode": mode}
		plugin.execute_query(query)

plugin.register("more_options", more_options_window)


if DB_TYPE == 'mysql':
	from dudehere.routines.database import MySQLDatabase as DatabaseAPI
else:
	from dudehere.routines.database import SQLiteDatabase as DatabaseAPI
	
if not vfs.exists(DATA_PATH): vfs.mkdir(DATA_PATH)

class MyDatabaseAPI(DatabaseAPI):
	def _initialize(self):
		schema_file = vfs.join(ROOT_PATH, 'resources/database/schema.%s.sql' % self.db_type)
		if self.run_script(schema_file, commit=False):
			self.execute('DELETE FROM version_redbeard WHERE 1')
			self.execute('INSERT INTO version_readbeard(db_version) VALUES(?)', [self.db_version])
			self.commit()
		
	def do_init(self):
		do_init = True
		try:
			test = self.query("SELECT 1 FROM version_redbeard WHERE db_version >= ?", [self.db_version], silent=True)
			if test:
				do_init = False
		except Exception, e:
			plugin.log(e)
			do_init = True
		return do_init
DB_VERSION = 6
if DB_TYPE == 'mysql':
	DB=MyDatabaseAPI(DB_ADDRESS, DB_NAME, DB_USER, DB_PASS, DB_PORT, version=DB_VERSION, connect=True)
else:
	DB=MyDatabaseAPI(DB_FILE, version=DB_VERSION, connect=False)

def update_run():
	if plugin.check_version(plugin.get_setting('version'), '1.0.2'):
		from dudehere.routines.window import Window
		class UpdateWindow(Window):
			def __init__(self, title, show_frame=True):
				super(self.__class__,self).__init__(title,width=750, height=650, columns=3, rows=10)
			
			def proceed(self):
				from dudehere.routines.trakt import TraktAPI
				trakt = TraktAPI()
				plugin.DB.connect()
				tv_favs = plugin.DB.query("SELECT trakt_id FROM tvshow_favorites", force_double_array=True, silent=True)
				tv_favs = tv_favs + plugin.DB.query("SELECT trakt_id FROM my_favorites WHERE media='tvshow'", force_double_array=True, silent=True)
				if tv_favs:
					for f in tv_favs:
						trakt.save_favorite('tvshow', f['trakt_id'])
				movie_favs = plugin.DB.query("SELECT trakt_id FROM tvshow_favorites", force_double_array=True, silent=True)	
				movie_favs = movie_favs + plugin.DB.query("SELECT trakt_id FROM my_favorites WHERE media='tvshow'", force_double_array=True, silent=True)
				if movie_favs:
					for f in movie_favs:
						trakt.save_favorite('movie', f['trakt_id'])
				plugin.DB.disconnect()
				plugin.set_setting('version', VERSION)
				self.close()
			
			def set_info_controls(self):
				import xbmcgui
				self.main_bg = xbmcgui.ControlImage(1, 1, 1280, 720, vfs.join(ROOT_PATH, 'fanart.jpg'))
				self.addControl(self.main_bg)

				label = self.create_label("redbeard: %s" % VERSION, alignment=2, textColor='0xFFFFA500', font='font13_title')
				self.add_label(label, 0, 0, pad_x=15, pad_y=10, columnspan=3)
				
				
				label = self.create_label(i18n(33055), alignment=2)
				self.add_label(label, 1, 0, pad_x=15, pad_y=10, columnspan=3, rowspan=4)
				
				
				self.create_button("proceed", i18n(33056))
				self.add_object("proceed", 8, 1)
				self.set_focus("proceed")
				self.set_object_event('action', "proceed", self.proceed)
		
		U = UpdateWindow('Red Beard Update %s' % VERSION)
		U.show()
		del U		
plugin.update_run = update_run

def first_run(upgrade=False):

	from dudehere.routines.window import Window
	from dudehere.routines.manager import Manager

	class FirstPage(Window):
		def __init__(self, title):
			super(self.__class__,self).__init__(title)
			self.overide_actions = {"next_button": self.erase_and_next}
			self.overide_strings = {"next_button": i18n(33011)}
			
		def erase_and_next(self):
			plugin.initialize_settings(upgrade)
			WM.next_page()
			
		def set_info_controls(self):
			def cancel():
				self.close()
				plugin.exit()
			content = i18n(33000)
			self.add_label(self.create_label(content), 0, 0, columnspan=4, rowspan=5, pad_x=15, pad_y=10)
			
			self.create_button("cancel", i18n(33013))
			self.add_object("cancel", 5, 0)
			self.set_object_event('action', 'cancel', cancel)
			
	class SecondPage(Window):
		def __init__(self, title):
			super(self.__class__,self).__init__(title, width=800, height=450, columns=4, rows=6)
			self.overide_strings = {"next_button": i18n(33014), "previous_button": i18n(33012)}
			
		def set_info_controls(self):	
			path = vfs.join(LANGUAGE_PATH, 'disclosure.txt', True)
			content  = vfs.read_file(path)
			self.add_label(self.create_label(content), 0, 0, columnspan=4, rowspan=5, pad_x=15, pad_y=10)
			
			self.create_button("decline", i18n(33015))
			self.add_object("decline", 5, 2)
			def decline():
				self.close()
				plugin.exit()
			self.set_object_event("action", "decline", decline)
			
	class ThirdPage(Window):	
		def set_info_controls(self):
			self.overide_strings = {"next_button": i18n(33011), "previous_button": i18n(33012)}
			content = i18n(33001)
			self.add_label(self.create_label(content), 0, 0, columnspan=4, rowspan=3, pad_x=15, pad_y=10)
			
			self.create_list('usage')
			self.add_object('usage', 2,0,3,4)
			self.add_list_items('usage', [i18n(30054), i18n(30055)], 0, allow_multiple=False, allow_toggle=False)
			
	
				
	class FourthPage(Window):
		def __init__(self, title):
			super(self.__class__,self).__init__(title, width=800, height=400, columns=4, rows=7)
			self.overide_strings = {"next_button": i18n(33011), "previous_button": i18n(33012)}
			
			def next_action():
				username = self.get_value('username')
				password = self.get_value('password')
				enabled = "true" if self.get_value('login') else 'false'
				addon_id = 'script.module.urlresolver'
				urlresolver = plugin.xbmcaddon.Addon(addon_id)
				urlresolver.setSetting('PremiumizeMeResolver_username', username)
				urlresolver.setSetting('PremiumizeMeResolver_password', password)
				urlresolver.setSetting('PremiumizeMeResolver_login', enabled)
				WM.next_page()
			
			self.overide_actions = {"next_button": next_action}
				
		def set_info_controls(self):
					
			self.add_label(self.create_label(i18n(33003)), 0, 0, columnspan=4, rowspan=2, pad_x=15, pad_y=10)
			
			self.add_label(self.create_label(i18n(33004), alignment=1), 2, 0, pad_x=15)
			username = plugin.get_setting('PremiumizeMeResolver_username', addon_id = 'script.module.urlresolver')
			password = plugin.get_setting('PremiumizeMeResolver_password', addon_id = 'script.module.urlresolver')
			enabled = plugin.get_setting('PremiumizeMeResolver_login', addon_id = 'script.module.urlresolver')=="true"
			
			self.create_input('username')
			self.add_object('username', 2, 1, columnspan=2)
			self.set_value('username', username)
			
			self.add_label(self.create_label(i18n(33005), alignment=1), 3, 0, pad_x=15)
			
			self.create_input('password')
			self.add_object('password', 3, 1, columnspan=2)
			self.set_value('password', password)
			
			self.create_checkbox('login', 'Enable Login')
			self.add_object('login', 4, 1)
			self.set_value('login', enabled)
			
			self.create_image('verified', ARTWORK + 'checked.png', aspectRatio=2)
			self.add_object('verified', 2, 3)
			self.get_object('verified').setVisible(False)

			
	class FifthPage(Window):
		def __init__(self, title):
			super(self.__class__,self).__init__(title, width=800, height=400, columns=4, rows=6)
			self.overide_strings = {"previous_button": i18n(33012)}
		
		def cancel(self):
			plugin.set_property('Abort', "true")
			self.close()
		
		def update_timeout(self, remain):
			self.timeout.setLabel(i18n(33050) % remain)
			
		def authorize(self):
			authorize_trakt()

		def set_info_controls(self):
			content = i18n(33008)
			self.add_label(self.create_label(content), 0, 0, columnspan=4, rowspan=3, pad_x=15, pad_y=10)
			
			self.url_label =  self.create_label('')
			self.placeControl(self.url_label, 3, 0, columnspan=4, pad_x=15, pad_y=10)

			self.create_button('authorize',  i18n(33017))
			self.add_object('authorize', 5, 2)	
			self.set_object_event('action', "authorize", self.authorize)
			
			self.create_button('finalize', i18n(33016))
			self.add_object('finalize', 5, 3)
			
	class ConfirmationPage(Window):	
		def set_info_controls(self):
			bg = vfs.join(ARTWORK, 'confirmation.png')
			self.create_image('background', bg, aspectRatio=0)
			self.add_object('background', 0, 0, rowspan=6, columnspan=3, pad_x=0, pad_y=0)
			self.add_label(self.create_label(i18n(33010), alignment=2, font="font14"), 0, 0, columnspan=3, rowspan=5, pad_x=15, pad_y=15)

	WM = Manager()
	WM.add_page(FirstPage(i18n(33021) % VERSION))
	WM.add_page(SecondPage(i18n(33022)  % VERSION))
	WM.add_page(ThirdPage(i18n(33023) % VERSION))
	WM.add_page(FourthPage(i18n(33024) % VERSION))
	WM.add_page(FifthPage(i18n(33025) % VERSION))
	WM.add_confirmation(ConfirmationPage(i18n(33027)))
	WM.build(vfs.join(ROOT_PATH, 'fanart.jpg'))
	def complete_setup():
		WM.show_confirmation()
		plugin.set_setting('setup_run', 'true')
		plugin.set_setting('version', VERSION)
		usage_mode = WM.get_value(2, 'usage')
		if usage_mode[1]:
			plugin.set_setting('advanced_mode', 'true')
	WM.set_object_event(4, "action", "finalize", complete_setup)
	WM.set_focus(0, 'next_button')
	WM.set_object_event(0, 'left', 'next_button', 'cancel')
	WM.set_object_event(0, 'right', 'cancel', 'next_button')
	WM.set_focus(1, 'decline')
	WM.set_object_event(1, 'left', 'next_button', 'decline')
	WM.set_object_event(1, 'left', 'decline', 'previous_button')
	WM.set_object_event(1, 'right', 'decline', 'next_button')
	WM.set_object_event(1, 'right', 'previous_button', 'decline')
	WM.set_focus(2, 'next_button')
	WM.set_object_event(2, 'left', 'next_button', 'previous_button')
	WM.set_object_event(2, 'right', 'previous_button', 'next_button')
	WM.set_object_event(2, 'up', 'next_button', 'usage')
	WM.set_object_event(2, 'up', 'previous_button', 'usage')
	WM.set_object_event(2, 'down', 'usage', 'next_button')
	WM.set_object_event(2, 'right', 'usage', 'next_button')
	WM.set_focus(3, 'username')
	WM.set_object_event(3, 'left', 'next_button', 'previous_button')
	WM.set_object_event(3, 'right', 'previous_button', 'next_button')
	WM.set_object_event(3, 'up', 'next_button', 'login')
	WM.set_object_event(3, 'up', 'previous_button', 'password')
	WM.set_object_event(3, 'up', 'password', 'username')
	WM.set_object_event(3, 'down', 'username', 'password')
	WM.set_object_event(3, 'down', 'password', 'login')
	WM.set_object_event(3, 'down', 'login', 'next_button')
	
	WM.set_focus(4, 'finalize')
	WM.set_object_event(4, 'left', 'finalize', 'authorize')
	WM.set_object_event(4, 'left', 'authorize', 'previous_button')
	WM.set_object_event(4, 'right', 'previous_button', 'authorize')
	WM.set_object_event(4, 'right', 'authorize', 'finalize')
	WM.show()
	plugin.set_property('Abort', "false")
plugin.first_run = first_run


def check_settings():
	import time
	import datetime
	d = datetime.datetime.now()
	unixtime = str(time.mktime(d.timetuple()))
	test = plugin.get_setting('settings_check')
	do_it = False
	if not test:
		do_it = True
		plugin.set_setting("settings_check", unixtime)
	else:
		do_it = (float(unixtime) - float(test)) < 86400
		
	if do_it:
		username = plugin.get_setting('PremiumizeMeResolver_username', addon_id = 'script.module.urlresolver')
		password = plugin.get_setting('PremiumizeMeResolver_password', addon_id = 'script.module.urlresolver')
		enabled = plugin.get_setting('PremiumizeMeResolver_login', addon_id = 'script.module.urlresolver')=="true"
		if not username or not password or not enabled:
			update_account()
		
			
def update_account():
	username = plugin.get_setting('PremiumizeMeResolver_username', addon_id = 'script.module.urlresolver')
	password = plugin.get_setting('PremiumizeMeResolver_password', addon_id = 'script.module.urlresolver')
	enabled = plugin.get_setting('PremiumizeMeResolver_login', addon_id = 'script.module.urlresolver')=="true"
	from dudehere.routines.windows import BaseWindow
	class SettingsWindow(BaseWindow):
		def __init__(self, *args, **kwargs):
				BaseWindow.__init__(self)
		
		def onInit(self):
			self.getControl(82001).setText(username)
			self.getControl(82002).setText(password)
			self.getControl(82003).setSelected(enabled)
				
		def onClick(self, controlID):
			if controlID in [82000, 82010]:
				self.close()
			elif controlID == 82011:
				username = self.getControl(82001).getText()
				passowrd = self.getControl(82002).getText()
				enabled = "true" if self.getControl(82003).isSelected() else "false"
				addon_id = 'script.module.urlresolver'
				urlresolver = plugin.xbmcaddon.Addon(addon_id)
				urlresolver.setSetting('PremiumizeMeResolver_username', username)
				urlresolver.setSetting('PremiumizeMeResolver_password', password)
				urlresolver.setSetting('PremiumizeMeResolver_login', enabled)
				self.close()
					
	skin_path = plugin.get_addon('script.module.dudehere.routines').getAddonInfo('path')
	s = SettingsWindow("settings.xml", skin_path)
	s.doModal()
	del s
plugin.register('update_account', update_account)

def main_menu():
	plugin.add_menu_item({'mode': 'tv_menu'}, {'title': "TV Shows"}, image=ARTWORK + 'tvshows.png')
	plugin.add_menu_item({'mode': 'movie_menu'}, {'title': "Movies"}, image=ARTWORK + 'movies.png')
	plugin.add_menu_item({'mode': 'settings_menu'}, {'title': "Settings and Tools"}, image=ARTWORK + 'settings.png')
	plugin.add_menu_item({'mode': 'authorize_trakt'}, {'title': "Authorize Trakt"}, image=ARTWORK + 'trakt.png', visible=validate_trakt()==False)
	plugin.add_menu_item({'mode': 'show_help'}, {'title': "Show Help"}, image=ARTWORK + 'about.png')
	plugin.eod(clear_search=True)
plugin.register('main', main_menu)

def tv_menu():
	plugin.add_menu_item({'mode': 'tv_favorites'}, {'title': STRINGS.map('my_favorites')}, image=ARTWORK + "favorites.png", visible=validate_trakt()==False)
	plugin.add_menu_item({'mode': 'tv_calendar'}, {'title': STRINGS.map('tv_calendar')}, image=ARTWORK + 'calendar.png', visible=validate_trakt)
	plugin.add_menu_item({'mode': 'tv_guide'}, {'title': STRINGS.map('guide')}, image=ARTWORK + 'tv_guide.png', visible=validate_trakt() and plugin.get_setting('enable_calendar')=="true")
	plugin.add_menu_item({'mode': 'tv_watchlist'}, {'title': STRINGS.map('watchlist')}, image=ARTWORK + 'watchlist.png', visible=validate_trakt)
	menu = ContextMenu()
	menu.add("Set Default List", {"mode": "set_default_list"})
	plugin.add_menu_item({'mode': 'next_on_trakt'}, {'title': STRINGS.map('on_next')}, image=ARTWORK + 'on_next.png', visible=validate_trakt() and plugin.get_setting('enable_onnext')=="true", menu=menu)
	plugin.add_menu_item({'mode': 'tv_custom_lists'}, {'title': STRINGS.map('custom_lists')}, image=ARTWORK + 'custom_list.png', visible=validate_trakt)
	plugin.add_menu_item({'mode': 'tv_recommended'}, {'title': STRINGS.map('tv_recommended')}, image=ARTWORK + 'recommended.png', visible=validate_trakt)
	plugin.add_menu_item({'mode': 'tv_popular'}, {'title': STRINGS.map('tv_popular')}, image=ARTWORK + 'popular.png')
	plugin.add_menu_item({'mode': 'tv_trending'}, {'title': STRINGS.map('tv_trending')}, image=ARTWORK + 'trending.png')
	
	plugin.add_menu_item({'mode': 'tv_genres'}, {'title': STRINGS.map('tv_genres')}, image=ARTWORK + 'genres.png')
	plugin.add_menu_item({'mode': 'tv_search'}, {'title': STRINGS.map('search')}, image=ARTWORK + 'search.png')
	plugin.add_menu_item({'mode': 'tv_search_advanced'}, {'title': STRINGS.map('advanced_search')}, image=ARTWORK + 'advanced_search.png')
	plugin.eod(clear_search=True)
plugin.register('tv_menu', tv_menu)

def movie_menu():
	plugin.add_menu_item({'mode': 'movie_favorites'}, {'title': STRINGS.map('my_favorites')}, image=ARTWORK + "favorites.png", visible=validate_trakt()==False)
	plugin.add_menu_item({'mode': 'movie_watchlist'}, {'title': STRINGS.map('watchlist')}, image=ARTWORK + 'watchlist.png', visible=validate_trakt)
	plugin.add_menu_item({'mode': 'movie_custom_lists'}, {'title': STRINGS.map('custom_lists')}, image=ARTWORK + 'custom_list.png', visible=validate_trakt)
	plugin.add_menu_item({'mode': 'movie_recommended'}, {'title': STRINGS.map('movie_recommended')}, image=ARTWORK + 'recommended.png', visible=validate_trakt)
	plugin.add_menu_item({'mode': 'movie_popular'}, {'title': STRINGS.map('movie_popular')}, image=ARTWORK + 'popular.png')
	plugin.add_menu_item({'mode': 'movie_trending'}, {'title': STRINGS.map('movie_trending')}, image=ARTWORK + 'trending.png')
	plugin.add_menu_item({'mode': 'movie_genres'}, {'title': STRINGS.map('movie_genres')}, image=ARTWORK + 'genres.png')
	plugin.add_menu_item({'mode': 'movie_search'}, {'title': STRINGS.map('search')}, image=ARTWORK + 'search.png')
	plugin.add_menu_item({'mode': 'movie_search_advanced'}, {'title': STRINGS.map('advanced_search')}, image=ARTWORK + 'advanced_search.png')
	plugin.eod(clear_search=True)
plugin.register('movie_menu', movie_menu)

def tv_genre_menu():
	genres = ["Action", "Adventure", "Animation", "Biography", "Comedy", "Crime", "Documentary", "Drama", "Family",
				"Fantasy", "Game-Show", "History", "Horror", "Music", "Musical", "Mystery", "Reality-TV", "Romance", "Sci-Fi", "Sport", "Thriller", "War",
				"Western"
	]

	for genre in genres:
		plugin.add_menu_item({'mode': 'tv_genre', "genre": genre}, {'title': genre}, image=ARTWORK + 'genres/%s.png' % genre.lower())
	plugin.eod(clear_search=True)
plugin.register('tv_genres', tv_genre_menu)
	

def movie_genre_menu():
	genres = ["Action", "Adventure", "Animation", "Biography", "Comedy", "Crime", "Documentary", "Drama", "Family",
				"Fantasy", "Film-Noir", "History", "Horror", "Music", "Musical", "Mystery", "Sci-Fi", "Sport", "Thriller", "War",
				"Western"
	]
	for genre in genres:
		plugin.add_menu_item({'mode': 'movie_genre', "genre": genre}, {'title': genre}, image=ARTWORK + 'genres/%s.png' % genre.lower())
	plugin.eod(clear_search=True)
plugin.register('movie_genres', movie_genre_menu)

def settings_menu():
	plugin.add_menu_item({'mode': 'update_account'}, {'title': STRINGS.map('update_account')}, image=ARTWORK + 'account.png')
	plugin.add_menu_item({'mode': 'cloud_manager'}, {'title': STRINGS.map('cloud_manager')}, image=ARTWORK + 'cloud_manager.png')
	plugin.add_menu_item({'mode': 'authorize_trakt'}, {'title': STRINGS.map('authorize_trakt')}, image=ARTWORK + 'trakt.png')
	plugin.add_menu_item({'mode': 'advanced_mode'}, {'title': STRINGS.map('enable_basic_mode')}, image=ARTWORK + "enable_basic.png", visible=validate_advanced())
	plugin.add_menu_item({'mode': 'advanced_mode'}, {'title': STRINGS.map('enable_advanced_mode')}, image=ARTWORK + "enable_advanced.png", visible=validate_advanced() is False)
	plugin.add_menu_item({'mode': 'default_views'}, {'title': "Set Default Views"}, image=ARTWORK + 'default_views.png', visible=plugin.get_setting('enable_default_views')=="true")
	plugin.add_menu_item({'mode': 'redbeard_settings', 'addon_id': 'plugin.video.redbeard'}, {'title': STRINGS.map('redbeard_settings')}, image=ARTWORK + 'settings.png')
	plugin.add_menu_item({'mode': 'urlresolver_settings', 'addon_id': 'script.module.urlresolver'}, {'title': STRINGS.map('urlresolver_settings')}, image=ARTWORK + 'urlresolver.png')
	plugin.add_menu_item({'mode': 'dudehere_routines_settings', 'addon_id': 'script.module.dudehere.routines'}, {'title': STRINGS.map('dudehere_routines_settings')}, image=ARTWORK + 'dudehere_routines.png')
	plugin.add_menu_item({'mode': 'clear_cache'}, {'title': STRINGS.map('clear_cache')}, image=ARTWORK + 'reset_cache.png')
	
	plugin.eod(clear_search=True)
plugin.register('settings_menu', settings_menu)

def default_views_menu():
	if not plugin.get_property('default_view_instructions.shown'):
		instructions = '''
Setting a default view is easy.
1) Change to the view you want to assign from the view options sub-menu under views (ie Media info).
2) Select the folder type from the list in the following menu.
3) Repeat for each folder type.
4) Relax and and enjoy the show!

'''
		plugin.dialog_textbox('Views Instructions', instructions)
		plugin.set_property('default_view_instructions.shown', "true")
	views = [
			('tvshow', 'TV Shows'),
			('season', 'Seasons'),
			('episode', 'Episodes'),
			('movie', 'Movies'),
			('folder', 'Folders'),
			('list', 'Lists')
	]

	for view, title in views:
		plugin.add_menu_item({'mode': 'set_default_view', "view": view}, {'title': title}, image=ARTWORK + 'default_views.png')
	plugin.eod(VIEWS.LIST_DEFAULT, 'movies', clear_search=True)
plugin.register('default_views', default_views_menu)



def tv_list():
	from dudehere.routines.trakt import TraktAPI
	trakt = TraktAPI()

	if plugin.mode == 		'tv_watchlist' or validate_trakt() is False:
		watchlist = []
	else:
		watchlist = trakt.get_watchlist_tvshows(simple=True)
	if plugin.mode == 		'tv_favorites':
		results = trakt.get_favorites('tvshow')
	elif plugin.mode == 		'tv_watchlist':
		results = trakt.get_watchlist_tvshows()
		if not results: return
		import re
		regex = re.compile("^(A )|(An )|(The )", re.IGNORECASE)
		def sort_results(title):
			title = regex.sub('', title['show']['title'], re.IGNORECASE)
			return title.lower()
		results.sort(key=lambda k: sort_results(k))
	elif plugin.mode == 	'tv_trending':
		results = trakt.get_trending_tvshows()
	elif plugin.mode == 	'tv_popular':
		results = trakt.get_popular_tvshows()
	elif plugin.mode ==		'tv_recommended':
		results = trakt.get_recommended_tvshows()
	elif plugin.mode ==		'tv_custom_list':
		results = trakt.get_custom_list(plugin.args['slug'], 'tvshows')
		if not results: return
		import re
		regex = re.compile("^(A )|(An )|(The )", re.IGNORECASE)
		def sort_results(title):
			title = regex.sub('', title['show']['title'], re.IGNORECASE)
			return title.lower()
		results.sort(key=lambda k: sort_results(k))
	elif plugin.mode ==		'tv_search':
		query = plugin.get_property('search.query.refesh')
		if query:
			plugin.clear_property('search.query')
			plugin.clear_property('search.query.refesh')
		else:
			query = plugin.dialog_input(i18n(30056))
			
		if query is None: 
			plugin.clear_property("search.query")
			return
		plugin.set_property('search.query', query)
		results = trakt.search(query, 'show')
		
	elif plugin.mode == 'tv_search_advanced':
		if 'page' in plugin.args:
			import ast
			filters =  ast.literal_eval(plugin.args['filters'])
			results = trakt.advanced_search('show', filters)
		else:	
			from resources.lib.windows import advanced_search
			s = advanced_search.AdvancedTVSearchWindow("tv_search.xml", ROOT_PATH)
			s.doModal()
			filters = s.response
			del s
			if filters:
				results = trakt.advanced_search('show', filters)
			else: return

	elif plugin.mode == 	'tv_similar':
		results = trakt.get_similar_tvshows(plugin.args['imdb_id'])
	elif plugin.mode == 	'tv_genre':
		from dudehere.routines import imdb
		results = imdb.search_tv_genre(plugin.args['genre'], page=plugin.get_arg('page'))

	if not results:
		return
	count = len(results)
	for record in results:
		if plugin.mode not in ['tv_genre']:
			record = trakt.process_record(record, media='tvshow')
		else:
			record['cast'] = []
		record['overlay'] = 1
		record['playcount'] = 0
		menu = ContextMenu()
		menu.add("Find Similar Shows", {"mode": "tv_similar", "imdb_id": record['imdb_id']})
		if plugin.mode == 	'tv_watchlist':
			menu.add(30037, {"mode": "tv_delete_from_watchlist", "imdb_id": record['imdb_id'], "name": record['title']}, script=True, visible=validate_trakt)
		else:
			if record['imdb_id'] in watchlist: 
				record['title'] = '[COLOR %s]%s[/COLOR]' % (WATCHLIST_COLOR, record['title'])
				menu.add(30037, {"mode": "tv_delete_from_watchlist", "imdb_id": record['imdb_id'], "name": record['title']}, script=True, visible=validate_trakt)
			else:
				menu.add(30038, {"mode": "tv_add_to_watchlist", "imdb_id": record['imdb_id']}, script=True, visible=validate_trakt)
				
		if plugin.mode ==	'tv_custom_list':
			menu.add(30039, {"mode": "delete_from_custom_list", "media": "tvshow", "imdb_id": record['imdb_id'], "slug": plugin.args['slug'], "name": record['title']}, script=True, visible=validate_trakt)
		else:
			menu.add(30040, {"mode": "add_to_custom_list", "media": "tvshow", "imdb_id": record['imdb_id']}, script=True, visible=validate_trakt)	
		if plugin.mode ==	'tv_favorites':
			menu.add('Delete Favorite', {"mode": "delete_from_favorites", "media": "tvshow", "title": record['title'], "trakt_id": record['trakt_id']}, script=True, visible=validate_trakt()==False)
		else:
			menu.add('Save as Favorite', {"mode": "add_to_favorites", "media": "tvshow",  "trakt_id": record['trakt_id']}, script=True, visible=validate_trakt()==False)
		
		menu.add(33060, {"mode": "set_default_view", "view": "tvshow"}, visible=validate_default_views)

		record['showtitle'] = record['title']
		if record['year']:
			try:
				record['title'] = u"%s (%s)" % (record['title'], record['year'])
			except UnicodeDecodeError:
				record['title'] = u"%s (%s)" % (record['title'].decode("utf-8"), record['year'])
			menu.add("Show Info", {"mode": "show_info"}, True)
		menu.add('Find or Update Fanart', {"mode": "update_series_fanart", "imdb_id": record['imdb_id'], "tvdb_id": record['tvdb_id'], "tmdb_id": record['tmdb_id'], "trakt_id": record['trakt_id'],  "fanart": record['backdrop_url']})
	
		plugin.add_menu_item({'mode': 'season_list', "slug": record['slug'], "imdb_id": record['imdb_id'], "tvdb_id": record['tvdb_id'], "title": record['showtitle'], "year": record['year'], "fanart": record['backdrop_url']}, record, menu=menu, total_items=count, replace_menu=True, image=record['cover_url'], fanart=record['backdrop_url'])
	menu = ContextMenu()
	next_page = 2 if not plugin.get_arg('page') else int( plugin.get_arg('page')) + 1
	if plugin.mode == 	'tv_genre':
		plugin.add_menu_item({'mode': 'tv_genre', "page": next_page, "genre": plugin.args['genre']}, {"title": "[COLOR %s]Next Page: %s >>[/COLOR]" % (NEXTPAGE_COLOR, next_page)}, total_items=count, menu=menu, replace_menu=True, image=ARTWORK + 'next.png', fanart='')
	elif plugin.mode == 'tv_search_advanced':
		filters['page'] = next_page
		plugin.add_menu_item({'mode': 'tv_search_advanced', "page": next_page, "filters": filters}, {"title": "[COLOR %s]Next Page: %s >>[/COLOR]" % (NEXTPAGE_COLOR, next_page)}, total_items=count, menu=menu, replace_menu=True, image=ARTWORK + 'next.png', fanart='')
	elif plugin.mode not in ['tv_custom_list', 'tv_search', 'tv_favorites']:
		plugin.add_menu_item({'mode': plugin.mode, "page": next_page}, {"title": "[COLOR %s]Next Page: %s >>[/COLOR]" % (NEXTPAGE_COLOR, next_page)}, menu=menu, total_items=count, replace_menu=True, image=ARTWORK + 'next.png', fanart='')
	plugin.eod(VIEWS.TV_DEFAULT, 'tvshows')	
plugin.register(['tv_watchlist', 'tv_trending', 'tv_popular', 'tv_recommended', 'tv_custom_list', 'tv_search', 'tv_favorites', 'tv_similar', 'tv_genre', 'tv_search_advanced'], tv_list)

def season_list():
	from dudehere.routines.trakt import TraktAPI
	from dudehere.routines.trakt import DB as TraktDB
	trakt = TraktAPI()
	imdb_id = plugin.args['imdb_id']
	tvdb_id = plugin.args['tvdb_id']
	results = trakt.get_show_seasons(imdb_id, tvdb_id)
	for record in results:
		if record['number'] > 0:
			menu = ContextMenu()
			season_id = record['ids']['trakt']
			if 'poster' in record:
				image = record['poster']
			else:
				image = ''
			fanart = plugin.get_arg('fanart')
			season = record['number']
			record = {"title": i18n(30057) % season}
			if validate_trakt():
				watched = trakt.get_watched_season(imdb_id, season, season_id)
				if watched is None: continue
				if watched: 
					record['playcount'] = 1
					record['overlay'] = 7
					menu.add(i18n(333065), {"mode": "set_unwatched", "media": "season", "id": season, "imdb_id": imdb_id}, visible=validate_trakt)
				else:
					menu.add(i18n(30058), {"mode": "set_watched", "media": "season", "id": season, "imdb_id": imdb_id}, visible=validate_trakt)
			menu.add("Binge Watch Season %s" % season, {"mode": "binge_season", "media": "season", "season": season, "imdb_id": imdb_id, "season_id": season_id, "showtitle": plugin.args['title']}, script=True)
			menu.add("Transmogrify Season %s" % season, {"mode": "transmogrify_season", "media": "season", "season": season, "imdb_id": imdb_id, "season_id": season_id, "showtitle": plugin.args['title']}, script=True, visible=validate_transmogrifier)
			
			menu.add(33061, {"mode": "set_default_view", "view": "season"}, visible=validate_default_views)
			plugin.add_menu_item({'mode': 'episode_list', "imdb_id": imdb_id, "season": season, "season_id": season_id, "fanart": fanart}, record, menu=menu, image=image, fanart=fanart)
	plugin.eod(VIEWS.SEASON_DEFAULT, "tvshows")
plugin.register('season_list', season_list)

def episode_list():
	from dudehere.routines.trakt import TraktAPI
	trakt = TraktAPI()
	show = trakt.get_show_info(plugin.args['imdb_id'])
	results = trakt.get_show_episodes(plugin.args['imdb_id'], plugin.args['season'])
	if validate_trakt():
		watched = trakt.get_watched_episodes(plugin.args['season_id'])
	else:
		watched = None
		
	count = len(results)	
	for record in results:
		record = trakt.process_record(record, media='episode', show=show, watched=watched)
		if record is False: continue
		if record['episode'] == 0: continue
		if plugin.get_setting('show_unaired_episodes') is False and record['aired'] is False: continue
		menu = ContextMenu()
		record['showtitle'] = show['title']
		record['year'] = show['year']
		record['imdb_id'] = plugin.args['imdb_id']
		if record['aired'] is False:
			formater = "[COLOR %s]%sx%s. %s - %s[/COLOR]" 
			subs = (UNAIRED_COLOR, record['season'], record['episode'], record['air_date'], record['title'])
			record['title'] = formater % subs
			plugin.add_menu_item({'mode': 'unaired_episode', "showtitle": record['showtitle'], "season": record['season'], "episode": record['episode']}, record, menu=menu, image=record['cover_url'], fanart=plugin.args['fanart'])
			continue
		else:
			hash_id = plugin.get_hash_id(record['imdb_id'], record['season'], record['episode'])
			if plugin.has_resume_point(hash_id):
				formater = u"[COLOR %s]%sx%s.[/COLOR] %s [COLOR %s][B]»[/B][/COLOR]"
				subs = (RESUME_COLOR, record['season'], record['episode'], record['title'], RESUME_COLOR)
			else:
				formater = "%sx%s. %s - %s" 
				subs = (record['season'], record['episode'], record['air_date'], record['title'])
		
		record['title'] = formater % subs
		
		if record['playcount'] == 0:
			menu.add(30041, {"mode": "set_watched", "media": "episode", "id": record['trakt_id'], "imdb_id": record['imdb_id'], "season": record['season'], "episode": record['episode']})
		else:
			if plugin.get_setting('hide_watched_episodes') == "true" : continue
			record['overlay'] = 7
			menu.add(30042, {"mode": "set_unwatched", "media": "episode", "id": record['trakt_id'], "imdb_id": record['imdb_id'], "season": record['season'], "episode": record['episode']})

		menu.add('Show Cached Sources', {"mode": "show_sources", "media": "episode", "imdb_id": record['imdb_id'], "tmdb_id": record['tmdb_id'], "year": record['year'], "showtitle": record['showtitle'], "season": record['season'], "episode": record['episode']})
		menu.add('Find More Sources', {"mode": "find_sources", "media": "episode", "imdb_id": record['imdb_id'], "tmdb_id": record['tmdb_id'], "year": record['year'], "showtitle": record['showtitle'], "season": record['season'], "episode": record['episode']})
		menu.add('Transmogrify', {"mode": "transmogrify_tvshow", "media": "episode", "imdb_id": record['imdb_id'], "tmdb_id": record['tmdb_id'], "year": record['year'], "showtitle": record['showtitle'], "season": record['season'], "episode": record['episode']},visible=validate_transmogrifier)
		menu.add(33062, {"mode": "set_default_view", "view": "episode"}, visible=validate_default_views)
		menu.add("Show Info", {"mode": "show_info"}, True)
		plugin.add_video_item({'mode': 'play_episode', "display": record['title'], "imdb_id": record['imdb_id'], "tmdb_id": record['tmdb_id'], "year": record['year'], "showtitle": record['showtitle'], "season": record['season'], "episode": record['episode']}, record, total_items=count, menu=menu, image=record['cover_url'], fanart=plugin.args['fanart'])
	plugin.eod(VIEWS.EPISODE_DEFAULT, 'tvshows')
plugin.register('episode_list', episode_list)	

def tv_calendar():
	from dudehere.routines.trakt import TraktAPI
	trakt = TraktAPI()	
	results = trakt.get_calendar_shows()
	if validate_trakt():
		watched = trakt.get_watched_history('shows')
	else:
		watched = []
	count = len(results)
	for record in results:
		record = trakt.process_record(record, media='episode', watched=watched)
		if record['season'] == 0 or record['episode']== 0: continue
		if validate_trakt() and watched:
			if record['imdb_id'] in watched:
				if record['season'] in watched[record['imdb_id']]:
					record['playcount'] = 1 if record['episode'] in watched[record['imdb_id']][record['season']] else 0
					if plugin.get_setting('hide_watched_episodes') == "true" and record['playcount'] == 1: continue
		menu = ContextMenu()
		menu.add("Find Similar Shows", {"mode": "tv_similar", "imdb_id": record['imdb_id']})
		if record['playcount'] == 0:
			menu.add(30041, {"mode": "set_watched", "media": "episode", "id": record['trakt_id'], "imdb_id": record['imdb_id'], "season": record['season'], "episode": record['episode']})
		else:
			record['overlay'] = 7
			menu.add(30042, {"mode": "set_unwatched", "media": "episode", "id": record['trakt_id'], "imdb_id": record['imdb_id'], "season": record['season'], "episode": record['episode']})
		menu.add(30044, {"mode": "season_list", "imdb_id": record['imdb_id'], "tvdb_id": record['tvdb_id'], "fanart": record['backdrop_url'], "title": record['showtitle']})
		menu.add('Show Cached Sources', {"mode": "show_sources", "media": "episode", "imdb_id": record['imdb_id'], "tmdb_id": record['tmdb_id'], "year": record['year'], "showtitle": record['showtitle'], "season": record['season'], "episode": record['episode']})
		menu.add('Find More Sources', {"mode": "find_sources", "media": "episode", "imdb_id": record['imdb_id'], "tmdb_id": record['tmdb_id'], "year": record['year'], "showtitle": record['showtitle'], "season": record['season'], "episode": record['episode']})
		menu.add('Transmogrify', {"mode": "transmogrify_tvshow", "media": "episode", "imdb_id": record['imdb_id'], "tmdb_id": record['tmdb_id'], "year": record['year'], "showtitle": record['showtitle'], "season": record['season'], "episode": record['episode']},visible=validate_transmogrifier)
		hash_id = plugin.get_hash_id(record['imdb_id'], record['season'], record['episode'])
		if plugin.has_resume_point(hash_id):
			record['title'] = u"[COLOR %s]%sx%s.[/COLOR] %s - %s [COLOR %s][B]»[/B][/COLOR]"% (RESUME_COLOR, record['season'], record['episode'], record['showtitle'], record['title'], RESUME_COLOR)
		else:
			record['title'] = "%sx%s. %s - %s" % (record['season'], record['episode'], record['showtitle'], record['title'])

		query = {'mode': 'play_episode', "display": record['title'], "imdb_id": record['imdb_id'], "tmdb_id": record['tmdb_id'], "year": record['year'], "showtitle": record['showtitle'], "season": record['season'], "episode": record['episode']}
		
		menu.add(33062, {"mode": "set_default_view", "view": "episode"}, visible=validate_default_views)
		menu.add("Show Info", {"mode": "show_info"}, True)
		plugin.add_video_item(query, record, total_items=count, image=record['cover_url'], fanart=record['backdrop_url'], menu=menu)
	plugin.eod(VIEWS.EPISODE_DEFAULT, 'tvshows')	
plugin.register('tv_calendar', tv_calendar)


def tv_guide():
	from resources.lib.windows import guide
	g = guide.GuideWindow("guide.xml", ROOT_PATH)
	g.doModal()
	del g

plugin.register('tv_guide', tv_guide)


def next_on_trakt():
	skin_path = plugin.get_addon('script.module.dudehere.routines').getAddonInfo('path')
	from dudehere.routines.windows.next_on_trakt import OnNextWindow
	g = OnNextWindow("onnext.xml", skin_path)
	g.doModal()
	del g

plugin.register('next_on_trakt', next_on_trakt)

def set_default_list():
	skin_path = plugin.get_addon('script.module.dudehere.routines').getAddonInfo('path')
	from dudehere.routines.windows.default_list import SetListWindow
	LI = SetListWindow("setlist.xml", skin_path)
	LI.doModal()
	del LI	
plugin.register('set_default_list', set_default_list)	

def find_fanart():
	skin_path = plugin.get_addon('script.module.dudehere.routines').getAddonInfo('path')
	from dudehere.routines.windows.fanart_editor import FanartEditor
	f = FanartEditor("fanart_editor.xml", skin_path)
	f.doModal()
	del f

plugin.register(["update_series_fanart", "update_movie_fanart"], find_fanart)

def manage_scrapers():
	skin_path = plugin.get_addon('script.module.dudehere.routines').getAddonInfo('path')
	from dudehere.routines.windows.torrent_scrapers import TorrentScrapersWindow
	w = TorrentScrapersWindow("torrent_scrapers.xml", skin_path)
	w.doModal()
	del w
plugin.register('manage_scrapers', manage_scrapers)

def toggle_scraper():
	from dudehere.routines.scrapers import ScraperPool
	Scraper = ScraperPool(load=False)
	Scraper.toggle_scraper_state(plugin.args['scraper'])
plugin.register('toggle_scraper', toggle_scraper)


def movie_list():
	from dudehere.routines.trakt import TraktAPI
	trakt = TraktAPI()
	if plugin.mode ==		'movie_watchlist'  or validate_trakt() is False:
		watchlist = []
	else:
		watchlist = trakt.get_watchlist_movies(simple=True)
	
	if plugin.mode ==		'movie_favorites':
		results = trakt.get_favorites('movie')
	elif plugin.mode ==		'movie_watchlist':
		results = trakt.get_watchlist_movies()
		if not results: return
		import re
		regex = re.compile("^(A )|(An )|(The )", re.IGNORECASE)
		def sort_results(title):
			title = regex.sub('', title['movie']['title'], re.IGNORECASE)
			return title.lower()
		results = sorted(results, key=lambda x: x['movie']['title'])
	elif plugin.mode ==		'movie_trending':
		results = trakt.get_trending_movies()
	elif plugin.mode ==		'movie_popular':
		results = trakt.get_popular_movies()
	elif plugin.mode ==		'movie_recommended':
		results = trakt.get_recommended_movies()
	elif plugin.mode ==		'movie_custom_list':
		results = trakt.get_custom_list(plugin.args['slug'], 'movie')
		if not results: return
		import re
		regex = re.compile("^(A )|(An )|(The )", re.IGNORECASE)
		def sort_results(title):
			title = regex.sub('', title['movie']['title'], re.IGNORECASE)
			return title.lower()
		results = sorted(results, key=lambda x: x['movie']['title'])
	elif plugin.mode == 	'movie_search':
		query = plugin.get_property('search.query.refesh')
		if query:
			plugin.clear_property('search.query')
			plugin.clear_property('search.query.refesh')
		else:
			query = plugin.dialog_input(i18n(30059))
		if query is None:
			plugin.clear_property("search.query")
			return
		plugin.set_property('search.query', query)
		results = trakt.search(query, 'movie')
	elif plugin.mode == 'movie_search_advanced':
		if 'page' in plugin.args:
			import ast
			filters =  ast.literal_eval(plugin.args['filters'])
			results = trakt.advanced_search('movie', filters)
		else:
			from resources.lib.windows import advanced_search
			s = advanced_search.AdvancedMovieSearchWindow("movie_search.xml", ROOT_PATH)
			s.doModal()
			filters = s.response
			del s
	
			if filters:
				results = trakt.advanced_search('movie', filters)
			else: return	
	elif plugin.mode == 	'movie_similar':
		results = trakt.get_similar_movies(plugin.args['imdb_id'])	
	elif plugin.mode == 	'movie_genre':
		from dudehere.routines import imdb
		results = imdb.search_movie_genre(plugin.args['genre'], page=plugin.get_arg('page'))
	count = len(results)
	if validate_trakt(): watched = trakt.get_watched_history('movies')
	if not results:
		return	
	from datetime import datetime
	for record in results:
		if plugin.mode not in ['movie_favorites', 'movie_genre']:
			record = trakt.process_record(record, media='movie')
		else:
			record['cast'] = []

		menu = ContextMenu()
		
		menu.add("Find Similar Movies", {"mode": "movie_similar", "imdb_id": record['imdb_id']})
		movie_title = record['title']
		if validate_trakt() and watched:
			if 'imdb' in watched and record['imdb_id'] in watched['imdb']:
				record['playcount'] = 1
				record['overlay'] = 7
				menu.add(30042, {"mode": "set_unwatched", "media": "movie", "id": record['imdb_id']})
			else:
				menu.add(30041, {"mode": "set_watched", "media": "movie", "id": record['imdb_id']})
		if plugin.mode ==	'movie_favorites':
			menu.add('Delete Favorite', {"mode": "delete_from_favorites", "media": "movie", "title": record['title'], "trakt_id": record['trakt_id']}, script=True, visible=validate_trakt()==False)
		else:
			menu.add('Save as Favorite', {"mode": "add_to_favorites", "media": "movie", "trakt_id": record['trakt_id']}, script=True, visible=validate_trakt()==False)
				
		if plugin.args['mode']=='movie_watchlist':
			menu.add(30037, {"mode": "movie_delete_from_watchlist", "imdb_id": record['imdb_id'], "name": movie_title}, script=True, visible=validate_trakt)
		else:
			if record['imdb_id'] in watchlist:
				record['title'] = '[COLOR %s]%s[/COLOR]' %  (WATCHLIST_COLOR, record['title'])
			menu.add(30038, {"mode": "movie_add_to_watchlist", "imdb_id": record['imdb_id']}, script=True, visible=validate_trakt)
			
		if plugin.args['mode']=='movie_custom_list':
			menu.add(30039, {"mode": "delete_from_custom_list", "media": "movie", "imdb_id": record['imdb_id'], "slug": plugin.args['slug'], "name": record['title']}, script=True, visible=validate_trakt)
		else:
			menu.add(30040, {"mode": "add_to_custom_list", "media": "movie", "imdb_id": record['imdb_id']}, script=True, visible=validate_trakt)	
		menu.add('Show Cached Sources', {"mode": "show_sources", "media": "movie", "imdb_id": record['imdb_id'], "tmdb_id": record['tmdb_id'], "year": record['year'], "title": movie_title}, script=True)
		menu.add('Find More Sources', {"mode": "find_sources", "media": "movie", "imdb_id": record['imdb_id'], "tmdb_id": record['tmdb_id'], "year": record['year'], "title": movie_title}, script=True)
		menu.add('Transmogrify', {"mode": "transmogrify_movie", "media": "movie", "imdb_id": record['imdb_id'], "tmdb_id": record['tmdb_id'], "year": record['year'], "title": movie_title}, script=True, visible=validate_transmogrifier)
		hash_id = plugin.get_hash_id(record['imdb_id'])
		has_resume = plugin.has_resume_point(hash_id)
		if record['year']:
			try:
				if has_resume:
					record['title'] = u"%s [COLOR %s](%s) [B]»[/B][/COLOR]" % (record['title'], RESUME_COLOR, record['year'])
				else:
					record['title'] = u"%s (%s)" % (record['title'], record['year'])
			except UnicodeDecodeError:
				if has_resume:
					record['title'] = u"%s [COLOR %s](%s) [B]»[/B][/COLOR]" % (record['title'].decode("utf-8"), RESUME_COLOR, record['year'])
				else:
					
					record['title'] = u"%s (%s)" % (record['title'].decode("utf-8"), record['year'])
					
		menu.add(33063, {"mode": "set_default_view", "view": "movie"}, visible=validate_default_views)
		menu.add("Show Info", {"mode": "show_info"}, True)
		menu.add('Find or Update Fanart', {"mode": "update_movie_fanart", "imdb_id": record['imdb_id'], "tmdb_id": record['tmdb_id'], "trakt_id": record['trakt_id'],  "fanart": record['backdrop_url']})
		plugin.add_video_item({'mode': 'play_movie', "imdb_id": record['imdb_id'], "tmdb_id": record['tmdb_id'], "year": record['year'], "title": movie_title}, record, menu=menu, total_items=count, image=record['cover_url'], fanart=record['backdrop_url'])
	menu = ContextMenu()
	next_page = 2 if not plugin.get_arg('page') else int( plugin.get_arg('page')) + 1
	if plugin.mode == 	'movie_genre':
		plugin.add_menu_item({'mode': 'movie_genre', "page": next_page, "genre": plugin.args['genre']}, {"title": "[COLOR %s]Next Page: %s >>[/COLOR]" % (NEXTPAGE_COLOR, next_page)}, menu=menu, replace_menu=True, image=ARTWORK + 'next.png', fanart='')
	elif plugin.mode == 'movie_search_advanced':
		filters['page'] = next_page
		plugin.add_menu_item({'mode': 'movie_search_advanced', "page": next_page, "filters": filters}, {"title": "[COLOR %s]Next Page: %s >>[/COLOR]" % (NEXTPAGE_COLOR, next_page)}, menu=menu, replace_menu=True, image=ARTWORK + 'next.png', fanart='')
	elif plugin.mode not in ['movie_custom_list', 'movie_search', 'movie_favorites']:
		plugin.add_menu_item({'mode': plugin.mode, "page": next_page}, {"title": "[COLOR %s]Next Page: %s >>[/COLOR]" % (NEXTPAGE_COLOR, next_page)}, menu=menu, replace_menu=True, image=ARTWORK + 'next.png', fanart='')

	plugin.eod(VIEWS.MOVIE_DEFAULT, 'movies')
	
plugin.register(['movie_watchlist', 'movie_trending', 'movie_popular', 'movie_recommended', 'movie_custom_list', 'movie_similar', 'movie_search', 'movie_favorites', 'movie_genre', 'movie_search_advanced'], movie_list)



def set_default_view():
	name, id = plugin.get_view()
	if not id:
		plugin.error_message('View Error', 'Could not detect current view') 
		return
	if plugin.args['view'] == 'tvshow':
		plugin.set_setting('default_tvshow_view', str(id))
		plugin.notify('Show view set', name)
		
	elif plugin.args['view'] == 'season':
		plugin.set_setting('default_season_view', str(id))
		plugin.notify('Season view set', name)
	
	elif plugin.args['view'] == 'episode':
		plugin.set_setting('default_episode_view', str(id))
		plugin.notify('Episode view set', name)	
	
	elif plugin.args['view'] == 'movie':
		plugin.set_setting('default_movie_view', str(id))
		plugin.notify('Movie view set', name)
	
	elif plugin.args['view'] == 'folder':
		plugin.set_setting('default_folder_view', str(id))
		plugin.notify('Folder view set', name)
	
	elif plugin.args['view'] == 'list':
		plugin.set_setting('default_list_view', str(id))
		plugin.notify('List view set', name)
	
	plugin.refresh()
		
plugin.register('set_default_view', set_default_view)

def add_to_favorites():
	from dudehere.routines.trakt import TraktAPI
	trakt = TraktAPI()
	title = trakt.save_favorite(plugin.args['media'], plugin.args['trakt_id'])
	if title:
		plugin.notify('Success', 'Added Favorite: %s' % title)
	else:
		plugin.notify('Failure', 'See log for details')	

plugin.register('add_to_favorites', add_to_favorites)

def delete_from_favorites():
	ok = plugin.dialog_confirm('Delete favorite', "click YES to continue", plugin.args['title'])
	if ok:
		from dudehere.routines.trakt import TraktAPI
		trakt = TraktAPI()
		trakt.delete_favorite(plugin.args['media'], plugin.args['trakt_id'])
		plugin.notify('Success', 'Favorite deleted: %s' % plugin.args['title'])
		plugin.refresh()
plugin.register('delete_from_favorites', delete_from_favorites)


def toggle_watched():
	from dudehere.routines.trakt import TraktAPI
	trakt = TraktAPI()
	re_watchlist = False
	if plugin.mode == 'set_watched':
		watched = True
		if plugin.args['media'] == 'episode' or plugin.args['media'] == 'season':
			watchlist = trakt.get_watchlist_tvshows(simple=True)
			re_watchlist = plugin.args['imdb_id'] in watchlist
	else:
		watched = False
	if plugin.args['media'] == 'season':
		trakt.set_watched_state(plugin.args['media'], plugin.args['imdb_id'], watched, plugin.args['id'])
	else:
		trakt.set_watched_state(plugin.args['media'], plugin.args['id'], watched)
	if re_watchlist: trakt.add_to_watchlist('shows', plugin.args['imdb_id'], id_type='imdb')
	hash_id = plugin.get_hash_id(plugin.get_arg('imdb_id',''),plugin.get_arg('season', ''),plugin.get_arg('episode', ''))
	plugin.clear_resume_point(hash_id)
	plugin.notify('Success', 'Watched' if watched == True else 'Unwatched')
	plugin.refresh()
plugin.register(['set_watched', 'set_unwatched'], toggle_watched)

def set_watched(media, imdb_id, season=None, episode=None):
	from dudehere.routines.trakt import TraktAPI
	trakt = TraktAPI()
	if media == 'episode':
		re_watchlist = False
		watchlist = trakt.get_watchlist_tvshows(simple=True)
		re_watchlist = imdb_id in watchlist
		episode =trakt.get_episode_details(imdb_id, season, episode, None)
		trakt_id = episode['trakt_id']
		trakt.set_watched_state(media, trakt_id, True)
		if re_watchlist: trakt.add_to_watchlist('shows', imdb_id, id_type='imdb')
	plugin.refresh()

def custom_list_menu():
	from dudehere.routines.trakt import TraktAPI
	trakt = TraktAPI()
	lists = trakt.get_custom_lists()
	media = 'tv' if plugin.mode == 'tv_custom_lists' else 'movie'
	DB.connect()
	results = DB.query("SELECT slug FROM lists WHERE media=?", [media], force_double_array=True)
	DB.disconnect()
	sync_lists = [l[0] for l in results]
	plugin.add_menu_item({'mode': 'new_custom_list', "media": media}, {"title": '***New Custom List***'}, image=ARTWORK+'/create_custom_list.png')
	for list in lists:
		menu = ContextMenu()
		if media == 'tv':
			menu.add("Show Next on Trakt", {"mode": "next_on_trakt", "slug": list['ids']['slug']}, script=True, visible=validate_trakt() and plugin.get_setting('enable_onnext')=="true")
		menu.add(30050, {"mode": "delete_custom_list", "slug": list['ids']['slug'], "name": list['name']}, script=True)
		plugin.add_menu_item({"mode": media + "_custom_list", 'slug': list['ids']['slug'], "media": media}, {"title": list['name']}, menu=menu, image=ARTWORK+'/custom_list.png')
	plugin.eod(VIEWS.LIST)
plugin.register(['tv_custom_lists', 'movie_custom_lists'], custom_list_menu)


def trakt_progress():
	plugin_url = "plugin://" + plugin.build_plugin_url({"mode": "main", "slug": plugin.args['slug'], "addon_id": ADDON_ID}, addon_id='script.nextontrakt')
	plugin.execute_url(plugin_url)
plugin.register('trakt_progress', trakt_progress)	

def new_custom_list():
	from dudehere.routines.trakt import TraktAPI
	trakt = TraktAPI()
	name = plugin.dialog_input(i18n(30072))
	if name:
		response = trakt.create_custom_list(name)
		if 'ids' in response.keys():
			plugin.notify(i18n(33019), i18n(30073), image=ARTWORK + 'trakt.png')
		else:
			plugin.notify(i18n(33020), i18n(30074), image=ARTWORK + 'trakt.png')
		plugin.refresh()
plugin.register('new_custom_list', new_custom_list)

def delete_custom_list():
	from dudehere.routines.trakt import TraktAPI
	trakt = TraktAPI()
	ok = plugin.dialog_confirm(i18n(30075), i18n(30076), plugin.args['name'])
	if ok:
		response = trakt.delete_custom_list(plugin.args['slug'])
		if response:
			plugin.refresh()
		else:
			plugin.notify(i18n(33020), i18n(30074), image=ARTWORK + 'trakt.png')

plugin.register('delete_custom_list', delete_custom_list)

def delete_from_custom_list():
	from dudehere.routines.trakt import TraktAPI
	trakt = TraktAPI()
	ok = plugin.dialog_confirm(i18n(30077), i18n(30076), plugin.args['name'])
	if plugin.args['media'] == 'movie':
		media = 'movies'
	else:
		media = 'shows'
	if ok:
		response = trakt.delete_from_custom_list(plugin.args['media'], plugin.args['slug'], plugin.args['imdb_id'])
		plugin.refresh()
		if response['deleted'][media]==1:
			plugin.notify(i18n(33019), i18n(30078), image=ARTWORK + 'trakt.png')
		elif response['not_found'][media]==1:
			plugin.notify(i18n(33028), i18n(30079), image=ARTWORK + 'trakt.png')
		else:
			plugin.notify(i18n(33020), i18n(30074), image=ARTWORK + 'trakt.png')
plugin.register('delete_from_custom_list', delete_from_custom_list)

def add_to_custom_list():
	from dudehere.routines.trakt import TraktAPI
	trakt = TraktAPI()
	lists = trakt.get_custom_lists()
	options = [lists[index]['name'] for index in xrange(len(lists))]
	index = plugin.dialog_select(i18n(30080), options)
	if plugin.args['media'] == 'movie':
		media = 'movies'
	else:
		media = 'shows'
	if index:
		slug = lists[index]['ids']['slug']
		id = plugin.args['imdb_id']
		id_type = 'imdb'
		response = trakt.add_to_custom_list(plugin.args['media'], slug, id, id_type)
		if response['added'][media]==1:
			plugin.notify(i18n(33019), i18n(30081), image=ARTWORK + 'trakt.png')
		elif response['existing'][media]==1:
			plugin.notify(i18n(33028), 'Already exists in list', image=ARTWORK + 'trakt.png')
		else:
			plugin.notify(i18n(33020), i18n(30074), image=ARTWORK + 'trakt.png')
plugin.register('add_to_custom_list', add_to_custom_list)	

def add_watchlist():
	from dudehere.routines.trakt import TraktAPI
	trakt = TraktAPI()
	if plugin.mode == 'tv_add_to_watchlist':
		media = 'shows'
	else:
		media = 'movies'

	id = plugin.args['imdb_id']
	id_type = 'imdb'
	response = trakt.add_to_watchlist(media, id, id_type=id_type)
	if response['added'][media]==1:
		plugin.refresh()
		plugin.notify(i18n(33019), i18n(30082), image=ARTWORK + 'trakt.png')
	elif response['existing'][media]==1:
		plugin.notify(i18n(33028), i18n(30083), image=ARTWORK + 'trakt.png')
	else:
		plugin.notify(i18n(33020), i18n(30074), image=ARTWORK + 'trakt.png')
plugin.register(['tv_add_to_watchlist', 'movie_add_to_watchlist'], add_watchlist)

def delete_from_watchlist():
	from dudehere.routines.trakt import TraktAPI
	print plugin.args
	trakt = TraktAPI()
	if plugin.mode == 'tv_delete_from_watchlist':
		media = 'shows'
	else:
		media = 'movies'
	ok = plugin.dialog_confirm(i18n(30084), i18n(30076), plugin.args['name'])
	if ok:
		id = plugin.args['imdb_id']
		id_type = 'imdb'
		response = trakt.delete_from_watchlist(media, id, id_type=id_type)

		if response['deleted'][media]==1:
			plugin.refresh()
			plugin.notify(i18n(33019), i18n(30085), image=ARTWORK + 'trakt.png')
		elif response['not_found'][media]==1:
			plugin.notify(i18n(33028), i18n(30086), image=ARTWORK + 'trakt.png')
		else:
			plugin.notify(i18n(33020), i18n(30076), image=ARTWORK + 'trakt.png')
		
plugin.register(['tv_delete_from_watchlist', 'movie_delete_from_watchlist'], delete_from_watchlist)

def show_help():
	import xbmcgui
	class Help(xbmcgui.WindowXMLDialog):
		def __init__(self, *args, **kwargs):
			xbmcgui.WindowXML.__init__(self)
		def onAction(self, action):
			action = action.getId()
			if action in [WINDOW_ACTIONS.ACTION_PREVIOUS_MENU, WINDOW_ACTIONS.ACTION_NAV_BACK]:
				self.close()
		def onClick(self, controlID):
			if controlID in [80000]: 
					self.close()
	H = Help("help.xml", ROOT_PATH)
	H.doModal()
	del H
			
plugin.register('show_help', show_help)

def advanced_mode():
	mode = 'false' if validate_advanced() else 'true'
	plugin.set_setting('advanced_mode', mode)
	plugin.refresh()
plugin.register('advanced_mode', advanced_mode)

def toggle_hevc():
	if plugin.get_setting('enable_hvec') == 'Yarr!' or plugin.get_property('enable_hvec') is False:
		plugin.set_setting('enable_hvec', 'Narr!')
		plugin.set_property('enable_hvec', "true")
		toggle_filter('x265', False)
	elif plugin.ADDON.get_setting('enable_hvec') == 'Narr!'  or plugin.get_property('enable_hvec') is True:
		plugin.set_setting('enable_hvec', 'Yarr!')
		plugin.set_property('enable_hvec', "false")
		toggle_filter('x265', True)
plugin.register('toggle_hevc', toggle_hevc)	


def toggle_filter(filter, value):
	cache_file = vfs.join(DATA_PATH, "filters.cache")
	if vfs.exists(cache_file):
		temp = plugin.load_data(cache_file)
	else:
		temp = [QUALITY.r_map[i] for i in range(1,9)] + ["x265"]
	if filter in temp:
		temp.remove(filter)
	if value:
		temp.append(filter)
	else:
		if filter in temp: temp.remove(filter)
	plugin.save_data(cache_file, temp)
plugin.register('toggle_filter', toggle_filter)

def set_quality():
	if plugin.get_setting('enable_result_filters') == "true":
		quality = plugin.get_setting('playback_quality')
		if plugin.get_property('quality') != quality:
			if quality == '1080p':
				toggle_filter('HD1080', True)
				toggle_filter('HD720', True)
				toggle_filter('HIGH', True)
				toggle_filter('HD', True)
			elif quality == '720p':
				toggle_filter('HD1080', False)
				toggle_filter('HD720', True)
				toggle_filter('HIGH', True)
				toggle_filter('HD', True)
			elif quality == '480p':
				toggle_filter('HD1080', False)
				toggle_filter('HD720', False)
				toggle_filter('HIGH', False)
				toggle_filter('HD', False)
			plugin.set_property('quality', quality)

def reset_redbeard():
	from dudehere.routines.window import Window
	class ResetWindow(Window):
		def __init__(self, title):
			super(self.__class__,self).__init__(title,width=700, height=300, columns=4, rows=6, quiet=True)
			self.draw()
			
		def set_info_controls(self):
			
			label = self.create_label(i18n(33031))
			self.add_label(label, 0, 0, columnspan=4, pad_x=15, pad_y=10)
			
			label = self.create_label(i18n(33032))
			self.add_label(label, 1, 0, columnspan=4, pad_x=15, pad_y=10)
			
			label = self.create_label(i18n(33033))
			self.add_label(label, 2, 0, columnspan=4, pad_x=15, pad_y=10)
			
			label = self.create_label(i18n(33034))
			self.add_label(label, 3, 0, columnspan=4, pad_x=15, pad_y=10)
			
			label = self.create_label(i18n(33035))
			self.add_label(label, 4, 0, columnspan=2, pad_x=15, pad_y=10)
			
			self.create_input('reset', _alignment=2)
			self.add_object('reset', 4, 1, columnspan=2)
			
			self.create_button('cancel', i18n(33036))
			self.add_object('cancel',  5, 1)
			
			self.create_button('confirm', i18n(33037))
			self.add_object('confirm',  5, 2)
			
		def confirm(self):
			if self.get_value('reset') != 'RESET':
				plugin.notify(i18n(33039), i18n(33040))
				return
			ok = plugin.dialog_confirm(i18n(33041), i18n(33042), i18n(33043))
			if ok:
				vfs.rm(DATA_PATH, quiet=True, recursive=True)
				self.close()
				plugin.exit()
			else:
				self.close()
			self.close()
		
	reset = ResetWindow(i18n(33044))
	reset.set_object_event('focus', 'reset')
	reset.set_object_event('down', 'reset', 'confirm')
	reset.set_object_event('up', 'confirm', 'reset')
	reset.set_object_event('left', 'confirm', 'cancel')
	reset.set_object_event('right', 'cancel', 'confirm')
	reset.set_object_event('up', 'cancel', 'reset')
	reset.set_object_event('action', 'cancel', reset.close)
	reset.set_object_event('action', 'confirm', reset.confirm)
	reset.show()
plugin.register("reset_redbeard", reset_redbeard)

def clear_cache(ok=False):
	if not ok:
		ok = plugin.dialog_confirm("Clear Cache", "Are you sure?", "This is your delete you cached data")
	if ok:
		from dudehere.routines.trakt import TraktAPI
		trakt = TraktAPI()
		trakt.delete_cache()
plugin.register('clear_cache', clear_cache)

def authorize_trakt():
	from dudehere.routines.trakt import TraktAPI
	trakt = TraktAPI()
	response = trakt.do_authorization()
	if response:
		plugin.notify("Trakt Authorization", "Success", image=ARTWORK + "trakt.png")
	else:
		plugin.notify("Trakt Authorization", "Failed", image=ARTWORK + "trakt.png")
	
plugin.register('authorize_trakt', authorize_trakt)	

def color_picker():
	colors = vfs.read_file(vfs.join(ROOT_PATH, 'resources/colors.txt')).splitlines()
	display = []
	for color in colors:
		color = color.lower()
		display.append("[COLOR %s]%s[/COLOR]" % (color, color))
	index = plugin.dialog_select(i18n(30089), display)
	if not index: return
	color = colors[index].lower()
	plugin.set_setting('custom_color_%s' % plugin.args['type'], color)
plugin.register('color_picker', color_picker)

def open_settings():
	xbmcaddon.Addon(id=plugin.args['addon_id']).openSettings()
plugin.register(['redbeard_settings', 'urlresolver_settings', 'transmogrifier_settings', 'dudehere_routines_settings'], open_settings)

def cloud_manager():
	plugin.run_command('RunAddon("script.redbeard.manager")')
plugin.register('cloud_manager', cloud_manager)

def manage_walter():
	plugin.run_command('RunAddon("service.walter.sobchak")')
plugin.register('manage_walter', manage_walter)

def show_info():
	xbmc.executebuiltin("Action(Info)")
plugin.register("show_info", show_info)	

def transmogrifier_queue():
	plugin.run_command('RunAddon("service.transmogrifier")')
plugin.register('manage_transmogrifier', transmogrifier_queue)

def find_sources():
	from dudehere.routines.scrapers import ScraperPool
	from dudehere.routines.premiumize import PremiumizeAPI
	import re
	pm = PremiumizeAPI()
	if plugin.args['media'] == 'movie':
		Scraper = ScraperPool(load=MOVIE_SCRAPERS, cache_results=False, return_cached_torrents=False)
		imdb_id = plugin.args['imdb_id']
		title = plugin.args['title']
		sources, raw_urls, results = Scraper.search_movies(title, False, imdb_id=imdb_id, return_sources=True)
	else:
		Scraper = ScraperPool(load=TV_SCRAPERS, cache_results=False, return_cached_torrents=False)
		title = plugin.args['showtitle']
		season = int(plugin.args['season'])
		episode = int(plugin.args['episode'])
		year = plugin.get_arg('year')
		sources, raw_urls, results = Scraper.search_tvshows(title, season, episode, year, False, return_sources=True)
	choice = plugin.dialog_select('Select a torrent', sources)
	if choice is not False:
		raw_url = raw_urls[choice]
		magnet = re.sub('^.*://', '', raw_url)
		response = pm.queue(magnet, False)
		if response['status'] == 'success':
			plugin.notify('Success', 'Added to transfer queue')
		else:
			plugin.notify('Failed', response['status'] + '. Please check your log for details')
			plugin.log(response)
		
plugin.register("find_sources", find_sources)

def show_sources():
	from dudehere.routines.scrapers import ScraperPool
	set_quality()
	if plugin.args['media'] == 'movie':
		Scraper = ScraperPool(load=MOVIE_LOAD_LIST, cache_results=plugin.get_setting('enable_result_caching')=="true")
		imdb_id = plugin.args['imdb_id']
		title = plugin.args['title']
		year = plugin.get_arg('year')
		sources, raw_urls, results = Scraper.search_movies(title, year, imdb_id=imdb_id, return_sources=True)
	else:
		Scraper = ScraperPool(load=TV_LOAD_LIST, cache_results=plugin.get_setting('enable_result_caching')=="true")
		imdb_id = plugin.args['imdb_id']
		title = plugin.args['showtitle']
		season = int(plugin.args['season'])
		episode = int(plugin.args['episode'])
		year = plugin.get_arg('year')
		sources, raw_urls, results = Scraper.search_tvshows(title, season, episode, year, imdb_id, return_sources=True)
	plugin.dialog_select('Available Source', sources)
plugin.register("show_sources", show_sources)

def transmogrify_season():
	from dudehere.routines.trakt import TraktAPI
	from dudehere.routines.scrapers import ScraperPool
	from dudehere.routines.transmogrifier import TransmogrifierAPI
	trakt = TraktAPI()
	from resources.lib.windows import transmogrify_season
	t = transmogrify_season.TransmogrifyWindow("transmogrify_season.xml", ROOT_PATH)
	show = trakt.get_show_info(plugin.args['imdb_id'])

	t.episodes = trakt.get_show_episodes(plugin.args['imdb_id'], plugin.args['season'])
	t.doModal()
	selections = t.selections
	if len(selections) == 0: return
	videos = []
	
	for episode in t.selections:
		Scraper = ScraperPool(load=TV_SCRAPERS, cache_results=plugin.get_setting('enable_result_caching')=="true")
		resolved_url = Scraper.search_tvshows(show['title'], plugin.args['season'], episode, show['year'], plugin.args['imdb_id'])
		if not resolved_url: continue
		filename = filename = "%s.S%02dE%02d" % (show['title'], int(plugin.args['season']), int(episode))
		video = {"type": "tvshow",
		"filename": filename,
		"addon": ADDON_ID,
		"host": 'premiumize.me',
		"url": resolved_url,
		}
		videos.append(video)
	TM = TransmogrifierAPI()
	response = TM.enqueue(videos)
	
plugin.register('transmogrify_season', transmogrify_season)

def transmogrify_source():
	from dudehere.routines.scrapers import ScraperPool
	from dudehere.routines.transmogrifier import TransmogrifierAPI
	set_quality()
	if plugin.mode == 'transmogrify_movie':
		Scraper = ScraperPool(load=MOVIE_SCRAPERS, cache_results=plugin.get_setting('enable_result_caching')=="true")
		imdb_id =  plugin.args['imdb_id']
		title = plugin.args['title']
		year = plugin.get_arg('year')
		filename = "%s (%s)" %(title,year)
		resolved_url = Scraper.search_movies(title, year, imdb_id=imdb_id)
		if not resolved_url: return
		video = {
			"type": "movie",
			"filename": filename,
			"url": resolved_url,
			"addon": ADDON_ID,
			"host": 'premiumize.me'
		}
		TM = TransmogrifierAPI()
		response = TM.enqueue([video])
	else:
		Scraper = ScraperPool(load=TV_SCRAPERS, cache_results=plugin.get_setting('enable_result_caching')=="true")
		imdb_id = plugin.args['imdb_id']
		title = plugin.args['showtitle']
		season = int(plugin.args['season'])
		episode = int(plugin.args['episode'])
		year = plugin.get_arg('year')
		filename = "%s.S%sE%s" % (title, str(season).zfill(2), str(episode).zfill(2))
		resolved_url = Scraper.search_tvshows(title, season, episode, year, imdb_id)
		if not resolved_url: return
		video = {
			"type": "tvshow",
			"filename": filename,
			"url": resolved_url,
			"addon": ADDON_ID,
			"host": 'premiumize.me'
		}
		TM = TransmogrifierAPI()
		response = TM.enqueue([video])
plugin.register(["transmogrify_movie", 'transmogrify_tvshow'], transmogrify_source)


def on_playback_stop():
	data = plugin.get_stream_stop_times()
	media = 'episode' if plugin.mode in ['play_episode'] else 'movie'
	refresh = False if  plugin.is_playlist() else True
	hash_id = plugin.get_hash_id(plugin.get_arg('imdb_id',''),plugin.get_arg('season', ''),plugin.get_arg('episode', ''))

	if data['percent'] >= WATCH_PERCENT:
		if media == 'episode':
			plugin.set_watched('episode', plugin.get_arg('showtitle',''), plugin.get_arg('year',''), plugin.get_arg('season',''), plugin.get_arg('episode',''))
		else:
			plugin.set_watched('movie', plugin.get_arg('title',''), plugin.get_arg('year',''))
		
		plugin.clear_resume_point(hash_id)
		#refresh = False	
	else:
		plugin.set_resume_point(hash_id)
		refresh = False
		
	if refresh:
		plugin.sleep(1000)
		plugin.refresh()
	
	plugin_url = plugin.get_property('Resume.Page')
	plugin.clear_property('Resume.Page')
	if  plugin_url.startswith('plugin://') is False:
		plugin_url = "plugin://" + plugin_url
	plugin.execute_url(plugin_url)
			
plugin.on_playback_stop = on_playback_stop


def binge_season():
	import xbmc, xbmcgui
	pl=xbmc.PlayList(1)
	pl.clear()
	from dudehere.routines.trakt import TraktAPI
	trakt = TraktAPI()
	results = trakt.get_show_episodes(plugin.args['imdb_id'], plugin.args['season'])
	watched = trakt.get_watched_episodes(plugin.args['season_id'])
	episodes = []
	for record in results:
		record = trakt.process_record(record, media='episode', watched=watched)
		if record is False: continue
		if record['episode'] == 0 or record['playcount'] == 1: 
			if record['playcount'] == 1: 
				episodes = []
			continue
		episodes += [record]

	for record in episodes:	
		record['showtitle'] = plugin.args['showtitle']
		record['title'] = "%s. %s" % (record['episode'], record['title'])
		record['imdb_id'] = plugin.args['imdb_id']
		query = {'mode': 'play_episode', "display": record['title'], "imdb_id": record['imdb_id'], "tmdb_id": record['tmdb_id'], "year": record['year'], "showtitle": record['showtitle'], "season": record['season'], "episode": record['episode']}
		plugin_url = plugin.get_plugin_url(query)
		liz = xbmcgui.ListItem(record['title'], record['cover_url'])
		xbmc.PlayList(1).add(plugin_url, liz)

	xbmc.Player().play(pl)
plugin.register("binge_season", binge_season)

def unaired_episode():
	plugin.notify('Arrrr me Matey!', 'Season %s Episode %s has not aired yet!' %(plugin.args['season'], plugin.args['episode']), timeout=3000)
	
plugin.register('unaired_episode', unaired_episode)

def play_episode():
	from dudehere.routines.scrapers import ScraperPool
	from dudehere.routines.trakt import TraktAPI
	set_quality()
	trakt = TraktAPI()
	Scraper = ScraperPool(load=TV_LOAD_LIST, cache_results=plugin.get_setting('enable_result_caching')=="true")
	Scraper.fallback = plugin.get_setting('enable_fallback') == "true"
	if plugin.mode == 'play_select_episode':
		Scraper.skip_autoplay = True
	imdb_id = plugin.args['imdb_id']
	title = plugin.args['showtitle']
	display = plugin.args['display']
	season = int(plugin.args['season'])
	episode = int(plugin.args['episode'])
	year = plugin.get_arg('year')
	resolved_url = Scraper.search_tvshows(title, season, episode, year, imdb_id)
	if not resolved_url: return
	metadata = trakt.get_episode_details(imdb_id, season, episode)
	if validate_transmogrifier_streaming():
		from dudehere.routines.transmogrifier import TransmogrifierAPI
		TM = TransmogrifierAPI()
		resolved_url = TM.get_streaming_url(resolved_url, host=Scraper.hostname, test_url=True)
	plugin.play_stream(resolved_url, metadata=metadata, title=display)
plugin.register(['play_episode', 'play_select_episode'], play_episode)

def play_movie():
	from dudehere.routines.scrapers import ScraperPool
	from dudehere.routines.trakt import TraktAPI
	set_quality()
	trakt = TraktAPI()
	Scraper = ScraperPool(load=MOVIE_LOAD_LIST, cache_results=plugin.get_setting('enable_result_caching')=="true")
	Scraper.fallback = plugin.get_setting('enable_fallback') == "true"
	if plugin.mode == 'play_select_movie':
		Scraper.skip_autoplay = True
	imdb_id = plugin.args['imdb_id']
	title = plugin.args['title']
	year = plugin.get_arg('year')
	metadata = trakt.get_movie_details(imdb_id)
	resolved_url = Scraper.search_movies(title, year, imdb_id=imdb_id)
	if not resolved_url: return
	if validate_transmogrifier_streaming():
		from dudehere.routines.transmogrifier import TransmogrifierAPI
		TM = TransmogrifierAPI()
		resolved_url = TM.get_streaming_url(resolved_url, host=Scraper.hostname, test_url=True)
	plugin.play_stream(resolved_url, metadata=metadata)
plugin.register(['play_movie', 'play_select_movie'], play_movie)

if __name__ == '__main__':
	check_settings()
	plugin.run()



	
