#!/usr/bin/python
# -*- coding: utf-8 -*-
PYTHONIOENCODING="UTF-8"

'''*
	Copyright (C) 2016 DudeHere

	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.

*'''

import re
import json
import xbmc
import xbmcgui
import xbmcaddon
from datetime import date
from dudehere.routines import *
from dudehere.routines import plugin
from dudehere.routines.windows import BaseWindow
from dudehere.routines.windows import WINDOW_ACTIONS


CONTROLS = enum(
	CLOSE=80000,
	CANCEL = 82010,
	ASEARCH = 82011,
	SEARCH=82001,
	CERTIFICATION=82002,
	NETWORK=82003,
	TV_GENRES=82004,
	MOVIE_GENRES=82003,
	YEAR=82004

)
tv_certifications = ["TV-Y", "TV-G", "TV-PG", "TV-14", "TV-MA"]
movie_certifications = ["G", "PG", "PG-13", "R", "NC-17"]
networks = ['ABC', 'AMC', 'Animal Planet', 'BBC', 'BET', 'Bravo', 'CBS', 'CMT', 'Comedy Central', 'Discovery Channel', 'Disney Channel', 'FX', 'Fox', 'Game Show Network', 'HBO', 'HGTV', 'IFC', 'ION Television', 'Lifetime Television', 'MTV', 'NBC', 'Netflix', 'Nickelodeon', 'Oxygen', 'PBS', 'Starz', 'Showtime', 'Syfy', 'TBS', 'TV Land', 'The WB', 'TLC', 'TNT', 'Travel Channel', 'The History Channel', 'USA', 'VH1',]
tv_genres = [u'Action', u'Adventure', u'Animation', u'Biography', u'Children', u'Comedy', u'Crime', u'Disaster', u'Documentary', u'Drama', u'Eastern', u'Family', u'Fantasy', u'Game Show', u'History', u'Home And Garden', u'Holiday', u'Horror', u'Mini Series', u'Music', u'Musical', u'Mystery', u'News', u'None', u'Reality', u'Romance', u'Science Fiction', u'Short', u'Soap', u'Special Interest', u'Sports', u'Sporting Event', u'Suspense', u'Talk Show', u'Thriller', u'War', u'Western']
movie_genres = [u'Action', u'Adventure', u'Animation', u'Comedy', u'Crime', u'Disaster', u'Documentary', u'Drama', u'Eastern', u'Family', u'Fan Film', u'Fantasy', u'Film Noir', u'History', u'Holiday', u'Horror', u'Indie', u'Music', u'Musical', u'Mystery', u'None', u'Road', u'Romance', u'Science Fiction', u'Short', u'Sports', u'Sporting Event', u'Suspense', u'Thriller', u'Tv Movie', u'War', u'Western']

class AdvancedTVSearchWindow(BaseWindow):
	def __init__(self, *args, **kwargs):
			BaseWindow.__init__(self)
	
	def onInit(self):
		self._certifications = []
		self._networks = []
		self._genres = []
		self.response = False
		
		for cert in tv_certifications:
			liz = xbmcgui.ListItem(cert, iconImage='')
			self.getControl(CONTROLS.CERTIFICATION).addItem(liz)
		for network in networks:
			liz = xbmcgui.ListItem(network, iconImage='')
			self.getControl(CONTROLS.NETWORK).addItem(liz)
			
		for genre in tv_genres:
			liz = xbmcgui.ListItem(genre, iconImage='')
			self.getControl(CONTROLS.TV_GENRES).addItem(liz)		
		
			
	
	def onClick(self, controlID):
		if controlID in [CONTROLS.CLOSE, CONTROLS.CANCEL]:
			self.close()
		elif controlID == CONTROLS.CERTIFICATION:
			liz = self.getControl(CONTROLS.CERTIFICATION).getSelectedItem()
			cert = liz.getLabel()
			if cert in self._certifications:
				self.getControl(CONTROLS.CERTIFICATION).getSelectedItem().setIconImage('')
				self._certifications.remove(cert)
			else:
				self.getControl(CONTROLS.CERTIFICATION).getSelectedItem().setIconImage('checked.png')
				self._certifications.append(cert)
		
		elif controlID == CONTROLS.NETWORK:
			liz = self.getControl(CONTROLS.NETWORK).getSelectedItem()
			network = liz.getLabel()
			if network in self._networks:
				self.getControl(CONTROLS.NETWORK).getSelectedItem().setIconImage('')
				self._networks.remove(network)
			else:
				self.getControl(CONTROLS.NETWORK).getSelectedItem().setIconImage('checked.png')
				self._networks.append(network)
		
		elif controlID == CONTROLS.TV_GENRES:
			liz = self.getControl(CONTROLS.TV_GENRES).getSelectedItem()
			genre = liz.getLabel()
			if genre in self._genres:
				self.getControl(CONTROLS.TV_GENRES).getSelectedItem().setIconImage('')
				self._genres.remove(genre)
			else:
				self.getControl(CONTROLS.TV_GENRES).getSelectedItem().setIconImage('checked.png')
				self._genres.append(genre)
				
		elif controlID == CONTROLS.ASEARCH:
			self.response = {"query": self.getControl(CONTROLS.SEARCH).getText(), "genres": self._genres, "networks": self._networks, "certifications": self._certifications}
			self.close()
			
class AdvancedMovieSearchWindow(BaseWindow):
	def __init__(self, *args, **kwargs):
			BaseWindow.__init__(self)
	
	def onInit(self):
		self._certifications = []
		self._genres = []
		self._year = ''
		self.response = False
		
		for cert in movie_certifications:
			liz = xbmcgui.ListItem(cert, iconImage='')
			self.getControl(CONTROLS.CERTIFICATION).addItem(liz)
			
		for genre in tv_genres:
			liz = xbmcgui.ListItem(genre, iconImage='')
			self.getControl(CONTROLS.MOVIE_GENRES).addItem(liz)
		
		
		for i in range(1920, date.today().year + 1):
			liz = xbmcgui.ListItem(str(i), iconImage='')
			self.getControl(CONTROLS.YEAR).addItem(liz)
		self.getControl(CONTROLS.YEAR).selectItem(self.getControl(CONTROLS.YEAR).size()-1)		
		
			
	
	def onClick(self, controlID):
		if controlID in [CONTROLS.CLOSE, CONTROLS.CANCEL]:
			self.close()
		elif controlID == CONTROLS.CERTIFICATION:
			liz = self.getControl(CONTROLS.CERTIFICATION).getSelectedItem()
			cert = liz.getLabel()
			if cert in self._certifications:
				self.getControl(CONTROLS.CERTIFICATION).getSelectedItem().setIconImage('')
				self._certifications.remove(cert)
			else:
				self.getControl(CONTROLS.CERTIFICATION).getSelectedItem().setIconImage('checked.png')
				self._certifications.append(cert)
		
		elif controlID == CONTROLS.MOVIE_GENRES:
			liz = self.getControl(CONTROLS.MOVIE_GENRES).getSelectedItem()
			genre = liz.getLabel()
			if genre in self._genres:
				self.getControl(CONTROLS.MOVIE_GENRES).getSelectedItem().setIconImage('')
				self._genres.remove(genre)
			else:
				self.getControl(CONTROLS.MOVIE_GENRES).getSelectedItem().setIconImage('checked.png')
				self._genres.append(genre)
				
		elif controlID == CONTROLS.YEAR:
			for i in xrange(self.getControl(CONTROLS.YEAR).size()):
				self.getControl(CONTROLS.YEAR).getListItem(i).setIconImage('')
			liz = self.getControl(CONTROLS.YEAR).getSelectedItem()
			year = liz.getLabel()
			if year == self._year:
				self.getControl(CONTROLS.YEAR).getSelectedItem().setIconImage('')
				self._year = ''
			else:
				self.getControl(CONTROLS.YEAR).getSelectedItem().setIconImage('checked.png')
				self._year = year
				
		elif controlID == CONTROLS.ASEARCH:
			self.response = {"query": self.getControl(CONTROLS.SEARCH).getText(), "genres": self._genres, "year": self._year, "certifications": self._certifications}
			self.close()			
			