import xbmcgui
from dudehere.routines import *
from dudehere.routines import plugin
from dudehere.routines.trakt import TraktAPI
from dudehere.routines.constants import WINDOW_ACTIONS
def validate_trakt():
	return plugin.get_setting('trakt_authorized') == "true"

CONTROLS = enum(
		LIST_MAX = 81009,
		LIST_MIN = 80999,
		WORKING = 80001,
		SHOW_TITLE = 82003,
		EPISODE_NUM = 82004,
		EPISODE_TITLE = 82005,
		OVERVIEW = 82006,
		THUMB = 82001,
		RATING = 82007,
		INFO = 82000,
		CLOSE = 80005,
		CONTEXT=91001
	
	)

class ContextWindow(xbmcgui.WindowXMLDialog):
	response = False
	def __init__(self, *args, **kwargs):
		xbmcgui.WindowXML.__init__(self)
	def onInit(self):
		items = ["Toggle Watched", "List Sources", "Add New Source", "Transmogrify"]
		list_items = []
		for i in items:
			icon = "context/%s.png" % i.replace(" ", "_").lower()
			liz = xbmcgui.ListItem(i, iconImage=icon)
			list_items.append(liz)
		self.getControl(CONTROLS.CONTEXT).addItems(list_items)
	
	def onAction(self, action):
		action = action.getId()
		if action in [WINDOW_ACTIONS.ACTION_PREVIOUS_MENU, WINDOW_ACTIONS.ACTION_NAV_BACK]:
			self.close()
		
	def onClick(self, controlID):
		if controlID == CONTROLS.CONTEXT:
			self.response = self.getControl(CONTROLS.CONTEXT).getSelectedPosition()
			self.close()
			
	def open(self):
		self.doModal()
		return self.response	

class GuideWindow(xbmcgui.WindowXMLDialog):

	last_id = CONTROLS.LIST_MAX
	def __init__(self, *args, **kwargs):
			xbmcgui.WindowXML.__init__(self)
	
	
	def load_shows(self):
		
		self.getControl(CONTROLS.WORKING).setVisible(True)
		for id in range(CONTROLS.LIST_MAX,CONTROLS.LIST_MIN,-1):
			self.getControl(id).setVisible(False)
		trakt = TraktAPI()
		self.shows = {}
		items = {}
		delta = 9
		import datetime as DT
		today = DT.date.today()
		
		if validate_trakt():
			watched = trakt.get_watched_history('shows')
		else:
			watched = []
				
		for id in range(CONTROLS.LIST_MAX,CONTROLS.LIST_MIN,-1):
			then = today - DT.timedelta(days=9-delta)
			liz = xbmcgui.ListItem('')
			liz.setLabel2(then.strftime("%A %B %d"))
			liz.setProperty("shadow", "heading.png")
			self.shows[id] = trakt.get_calendar_daily_shows(delta=9-delta)
			#self.shows[id] = trakt.get_calendar("all/shows", delta=9-delta)
			items[id] = [liz]
			for rec in self.shows[id]:
				if rec["episode"]['season'] == 0 or rec["episode"]['number'] == 0: continue
				query = {"mode": "play_episode", "showtitle": rec['show']['title'], "year": rec['show']['year'], "imdb_id": rec['show']['ids']['imdb'], "display": rec['show']['title'], "season": rec["episode"]['season'], "episode": rec["episode"]['number']}
				plugin_url = plugin.get_plugin_url(query)
				display = "%s\n%s" % (rec['show']['title'], rec['episode']["title"])
				liz = xbmcgui.ListItem(display)
				liz.setProperty("watched", "0")
				shadow = 'unwatched.png'
				if validate_trakt() and watched:
					if rec['show']['ids']['imdb'] in watched:
						if rec["episode"]['season'] in watched[rec['show']['ids']['imdb']]:
							if rec["episode"]['number'] in watched[rec['show']['ids']['imdb']][rec["episode"]['season']]:
								shadow = 'watched.png'
								liz.setProperty("watched", "1")

				liz.setProperty("shadow", shadow)
				liz.setProperty("url", plugin_url)
				items[id].append(liz)
			self.getControl(id).reset()	
			self.getControl(id).addItems(items[id])	
			delta -= 1
		
		self.setFocusId(CONTROLS.LIST_MAX)
		self.getControl(CONTROLS.WORKING).setVisible(False)
		for id in range(CONTROLS.LIST_MAX,CONTROLS.LIST_MIN,-1):
			self.getControl(id).setVisible(True)	
	
	
	def update_info(self, controlID, position=None):
		if position is None:
			position = self.getControl(controlID).getSelectedPosition()

		if position == 0:
			self.clear_info()
			return
		
		try:
				rec = self.shows[controlID][self.getControl(controlID).getSelectedPosition()-1]
		except:
			rec = False
			self.clear_info()
		if rec:
			self.getControl(CONTROLS.INFO).setVisible(True)
			self.getControl(CONTROLS.SHOW_TITLE).setLabel(rec['show']['title'])
			self.getControl(CONTROLS.EPISODE_TITLE).setLabel(rec['episode']['title'])
			num = "%s x %s" % (rec["episode"]['season'], rec["episode"]['number'])
			self.getControl(CONTROLS.EPISODE_NUM).setLabel(num)
			if 'images' in rec['episode']:
				if 'screenshot' in rec['episode']['images']:
					thumb = rec['episode']['images']['screenshot']['thumb']
					thumb = thumb if thumb is not None else 'no_thumb.png'
					self.getControl(CONTROLS.THUMB).setImage(thumb)
			self.getControl(CONTROLS.OVERVIEW).setText(rec['episode']['overview'])
			
			rating = rec['episode']['rating']
			width = int(round((rating / 10 * 200)))
			self.getControl(CONTROLS.RATING).setWidth(width)
			#network = 'network_logos/' + re.sub(' +\(.+?\)$', '', rec['show']['network'].lower()).replace(' ', '-') + '.png'

	def clear_info(self):
		self.getControl(CONTROLS.INFO).setVisible(False)
		
		
	def onInit(self):
		self.clear_info()
		self.load_shows()
		
	def onAction(self, action):
		action = action.getId()
		if action in [WINDOW_ACTIONS.ACTION_PREVIOUS_MENU, WINDOW_ACTIONS.ACTION_NAV_BACK]:
			self.close()
		
		try:
			if action in [WINDOW_ACTIONS.ACTION_SHOW_INFO, WINDOW_ACTIONS.ACTION_CONTEXT_MENU]:
				controlID = self.getFocus().getId()
				if controlID <= CONTROLS.LIST_MAX and controlID > CONTROLS.LIST_MIN:
					plugin_url = self.getControl(controlID).getSelectedItem().getProperty("url")
					if plugin_url:
						rec = self.shows[controlID][self.getControl(controlID).getSelectedPosition()-1]
						context = ContextWindow('context.xml', ROOT_PATH)
						response = context.open()
						del context
						if response is False: return
						if response == 0:
							trakt_id = rec['episode']['ids']['trakt']
							watched = self.getControl(controlID).getSelectedItem().getProperty("watched")
							trakt = TraktAPI()
							if watched == "1":
								self.getControl(controlID).getSelectedItem().setProperty("watched", "0")
								self.getControl(controlID).getSelectedItem().setProperty("shadow", "unwatched.png")
								trakt.set_watched_state('episode', trakt_id, False)
							else:
								self.getControl(controlID).getSelectedItem().setProperty("watched", "1")
								self.getControl(controlID).getSelectedItem().setProperty("shadow", "watched.png")
								trakt.set_watched_state('episode', trakt_id, True)
							plugin.notify('Success', 'Watched' if watched == '0' else 'Unwatched')
						elif response == 1:
							query = {'mode': 'show_sources',
									"media": "episode",  
									"imdb_id": rec['show']['ids']['imdb'], 
									"showtitle": rec['show']['title'], 
									"year": rec['show']['year'], 
									"season": rec['episode']['season'],
									"episode": rec['episode']['number']
							}
							plugin.execute_query(query)
						elif response == 2:
							query = {'mode': 'find_sources',
									"media": "episode",  
									"showtitle": rec['show']['title'], 
									"season": rec['episode']['season'],
									"episode": rec['episode']['number']
							}
							plugin.execute_query(query)
						elif response == 3:
							query = {'mode': 'transmogrify_tvshow',
									"imdb_id": rec['show']['ids']['imdb'], 
									"showtitle": rec['show']['title'], 
									"year": rec['show']['year'], 
									"season": rec['episode']['season'],
									"episode": rec['episode']['number']
							}
							plugin.execute_query(query)
		except:
			pass
		
		try:
			controlID = self.getFocus().getId()
			if controlID <= CONTROLS.LIST_MAX and controlID > CONTROLS.LIST_MIN and self.getControl(controlID).getSelectedPosition() > 0:
				self.update_info(controlID)	
			else:
				self.clear_info()
		except:
			pass
		
	def onClick(self, controlID):
		if controlID <= CONTROLS.LIST_MAX and controlID > CONTROLS.LIST_MIN:
			plugin_url = self.getControl(controlID).getSelectedItem().getProperty("url")
			if plugin_url:
				self.close()
				plugin.play_url(plugin_url)
		elif controlID==CONTROLS.CLOSE:
			self.close()

			
	def onFocus(self, controlID):
		if controlID <= CONTROLS.LIST_MAX and controlID > CONTROLS.LIST_MIN:
			if controlID != self.last_id:
				selected_position = self.getControl(self.last_id).getSelectedPosition()
				size = self.getControl(controlID).size()
				if selected_position > size:
					selected_position = size - 1
				self.getControl(controlID).selectItem(selected_position)
			self.last_id = controlID